
#Script for statistical analysis and figures in:
#Gingins S, Roche DG, Bshary R (submitted). Mutualistic cleaner fish maintains high escape performance despite privileged relationship with predators. For questions or to notify the authors if any errors are identified in the data, please contact Simon Gingins (simon.gingins@unine.ch) or Dominique Roche (dominique.roche@unine.ch).

library(languageR)
library(data.table)
library(nlme)
library(ggplot2)
library(multcomp)
library(car)
library(effects)
library(plyr)
library(lsmeans)
library(FactoMineR)
library(lme4)
library(mgcv)
library(lmerTest)
library(lattice)
library(corrplot)
library(GGally)

data_full <- read.table("Fast-starts_data.txt", header=T)
summary(data_full)

# First I create a subset excluding the trials where the stimulus fell frontally and dorsally (keeping only angles between 25-155)

a<- subset(data_full, data_full$Angle_to_stimulus >=25)
a<- subset(a, a$Angle_to_stimulus <=156)
a<-droplevels(a)
summary(a)

# for individuals AA & Z, the first 5 & 4 trials (respectively) were filmed with the wrong framerate and hence were discarded, so I change the trial number for these two

a$Video[a$Individual=="AA-ad"] <- a$Video[a$Individual=="AA-ad"] - 5
a$Video[a$Individual=="Z-ad"] <- a$Video[a$Individual=="Z-ad"] - 4


# then I create some new variables to have the values in ms instead of frames

a$Latency_ms <- a$Response_latency_frames*2.4
a$Stage1_ms <- a$Stage1_frames*2.4
a$Stage2_ms <- a$Stage2_frames*2.4
a$Stage_1_2_ms <- a$Total_st1_2*2.4
a$Turning_rate_ms <- a$Turning_rate_per_frame/2.4
a$Status <- factor(a$Status)
a$color[a$Status=="juvenile"] <- "blue"
a$color[a$Status=="adult"] <- "red"
a$pch[a$Status=="juvenile"] <- 4
a$pch[a$Status=="adult"] <- 1

# Creating a variable for the cumulative distance after onset of response (excluding distance traveled before 1st head movement)

a$Cum_dist2 <- a$Cum_dist - a$Dist_before_react

# centering the explanatory variables "distance to stimulus", "angle to stimulus" and "total length"


a$Dist_to_stimulus_c <- a$Dist_to_stimulus - mean(a$Dist_to_stimulus)
a$Angle_to_stimulus_c <- a$Angle_to_stim - mean(a$Angle_to_stim)
a$TL_c <- a$TL - mean(a$TL)

# new vector species for easier plotting (re-ordered)

a$Species2 <- factor(a$Species, levels=c("Labroides_dimidiatus", "Halichoeres_melanurus", "Pseudocheilinus_hexataenia", "Thalassoma_lunare", "Labrichthys_unilineatus", "Hemigymnus_melapterus"), labels=c("L. dim.", "H. melan.", "P. hex.", "T. lun.", "L. uni.", "H. melap."))


########### Info per individuals

# number of trials per individual included in analysis
table(a$Individual)
min(table(a$Individual))
max(table(a$Individual))
mean(table(a$Individual))
sd(table(a$Individual))

# total number of trials per individual

maxtrials <- as.data.table(a)[order(Individual, -Video), head(.SD,1), by=Individual]
maxtrials <- as.data.frame(maxtrials)
maxtrials
max(maxtrials$Video)
mean(maxtrials$Video)
sd(maxtrials$Video)

# plotting dates of the trials per species

a$Video_file <- as.character(a$Video_file)
a$date <- substr(a$Video_file, nchar(a$Video_file)-13, nchar(a$Video_file)-4)
a$date <- gsub("-", "/", a$date)
a$date<- strptime(a$date, "%d/%m/%Y")

plot(a$Species2, a$date)

# subsets for juveniles & adults

aA <- subset(a, a$Status=="adult")
aA <- droplevels(aA)

aJ <- subset(a, a$Status=="juvenile")
aJ <- droplevels(aJ)


# plot the dates for juveniles & adults separately

par(mfrow=c(1,2))
plot(jitter(as.numeric(aA$Species2)), aA$date, ylim=c(as.POSIXct('2013-01-01', format="%Y-%m-%d"), as.POSIXct('2013-03-05', format="%Y-%m-%d")), xlab="Species", ylab="Date", main="Adult Trial Dates")
plot(jitter(as.numeric(aJ$Species2)), aJ$date, xlab="Species", ylab="Date", main="Juvenile Trial Dates")


# plot fast-start durations (in frames)

plot(jitter(as.numeric(aA$Species2)), aA$Total_st1_2, xlab="Species", ylab="Duration [frames]", main="Fast-start duration ad.")
plot(jitter(as.numeric(aJ$Species2)), aJ$Total_st1_2, xlab="Species", ylab="Duration [frames]", main="Fast-start duration juv.")

par(mfrow=c(1,1))
plot(jitter(as.numeric(a$Species2)), a$Total_st1_2, xlab="Species", ylab="Duration [frames]", main="Fast-start duration")


mean(a$Total_st1_2, na.rm=T)
mean(aA$Total_st1_2, na.rm=T)
mean(aJ$Total_st1_2, na.rm=T)

# function to test for multicolinearity in lmer models. Function written by John Lefcheck, code and explanations available on his website https://jonlefcheck.net/2012/12/28/dealing-with-multicollinearity-using-variance-inflation-factors/

vif.lme <- function (fit) {
  ## adapted from rms::vif
  v <- vcov(fit)
  nam <- names(fixef(fit))
  ## exclude intercepts
  ns <- sum(1 * (nam == "Intercept" | nam == "(Intercept)"))
  if (ns > 0) {
    v <- v[-(1:ns), -(1:ns), drop = FALSE]
    nam <- nam[-(1:ns)] }
  d <- diag(v)^0.5
  v <- diag(solve(v/(d %o% d)))
  names(v) <- nam
  v }

###############################################################################################################################
######################## lmer Analysis ########################################################################################
###############################################################################################################################


########## 1.1) LATENCY - Adults #########

lat.ad <- lmer(log(Latency_ms) ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aA)

summary(lat.ad)
anova(lat.ad)

# model validation

plot(lat.ad, which=c(1)) 
res.lat.ad <- resid(lat.ad)

hist(res.lat.ad)
qqPlot(res.lat.ad) 

plot(res.lat.ad ~ aA$Species)
plot(res.lat.ad ~ aA$Dist_to_stimulus)
plot(res.lat.ad ~ aA$Angle_to_stimulus)
plot(res.lat.ad ~ aA$Video)
plot(res.lat.ad ~ aA$Observer)

vif.lme(lat.ad)

# Plotting model predictions

plot(effect("Species2", lat.ad))


########## 1.2) LATENCY - Juveniles #########

lat.juv <- lmer(log(Latency_ms) ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aJ)

summary(lat.juv)
anova(lat.juv)

# model validation

plot(lat.juv, which=c(1)) 
res.lat.juv <- resid(lat.juv)

hist(res.lat.juv)
qqPlot(res.lat.juv) 

plot(res.lat.juv ~ aJ$Species)
plot(res.lat.juv ~ aJ$Dist_to_stimulus)
plot(res.lat.juv ~ aJ$Angle_to_stimulus)
plot(res.lat.juv ~ aJ$Video)
plot(res.lat.juv ~ aJ$Observer)

vif.lme(lat.juv)

# Plotting model predictions

plot(effect("Species2", lat.juv))


########## 2.1) CUMULATIVE DISTANCE - Adults #########

cum.ad <- lmer(Cum_dist2 ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aA)

summary(cum.ad)
anova(cum.ad)

# model validation

plot(cum.ad, which=c(1)) 
res.cum.ad <- resid(cum.ad)

hist(res.cum.ad)
qqPlot(res.cum.ad) 

plot(res.cum.ad ~ aA$Species)
plot(res.cum.ad ~ aA$Dist_to_stimulus)
plot(res.cum.ad ~ aA$Angle_to_stimulus)
plot(res.cum.ad ~ aA$Video)
plot(res.cum.ad ~ aA$Observer)

vif.lme(cum.ad)

# Plotting model predictions

plot(effect("Species2", cum.ad))


########## 2.2) CUMULATIVE DISTANCE - Juveniles #########

cum.juv <- lmer(Cum_dist2 ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aJ)

summary(cum.juv)
anova(cum.juv)

# model validation

plot(cum.juv, which=c(1)) 
res.cum.juv <- resid(cum.juv)

hist(res.cum.juv)
qqPlot(res.cum.juv) 

plot(res.cum.juv ~ aJ$Species)
plot(res.cum.juv ~ aJ$Dist_to_stimulus)
plot(res.cum.juv ~ aJ$Angle_to_stimulus)
plot(res.cum.juv ~ aJ$Video)
plot(res.cum.juv ~ aJ$Observer)

vif.lme(cum.juv)

# Plotting model predictions

plot(effect("Species2", cum.juv))

########## 3.1) ACCELERATION - Adults #########

acc.ad <- lmer(Max_acceleration_m_s2 ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aA)

summary(acc.ad)
anova(acc.ad)

# model validation

plot(acc.ad, which=c(1)) 
res.acc.ad <- resid(acc.ad)

hist(res.acc.ad)
qqPlot(res.acc.ad) 

plot(res.acc.ad ~ aA$Species)
plot(res.acc.ad ~ aA$Dist_to_stimulus)
plot(res.acc.ad ~ aA$Angle_to_stimulus)
plot(res.acc.ad ~ aA$Video)
plot(res.acc.ad ~ aA$Observer)

vif.lme(acc.ad)

# Plotting model predictions

plot(effect("Species2", acc.ad))

########## 3.2) ACCELERATION - Juveniles #########

acc.juv <- lmer(Max_acceleration_m_s2 ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aJ)

summary(acc.juv)
anova(acc.juv)

# model validation

plot(acc.juv, which=c(1)) 
res.acc.juv <- resid(acc.juv)

hist(res.acc.juv)
qqPlot(res.acc.juv) 

plot(res.acc.juv ~ aJ$Species)
plot(res.acc.juv ~ aJ$Dist_to_stimulus)
plot(res.acc.juv ~ aJ$Angle_to_stimulus)
plot(res.acc.juv ~ aJ$Video)
plot(res.acc.juv ~ aJ$Observer)

vif.lme(acc.juv)

# Plotting model predictions

plot(effect("Species2", acc.juv))


########## 4.1) VELOCITY - Adults ######### 

vel.ad <- lmer(Max_velocity_cm_s ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aA)

summary(vel.ad)
anova(vel.ad)

# model validation

plot(vel.ad, which=c(1)) 
res.vel.ad <- resid(vel.ad)

hist(res.vel.ad)
qqPlot(res.vel.ad) 

plot(res.vel.ad ~ aA$Species)
plot(res.vel.ad ~ aA$Dist_to_stimulus)
plot(res.vel.ad ~ aA$Angle_to_stimulus)
plot(res.vel.ad ~ aA$Video)
plot(res.vel.ad ~ aA$Observer)

vif.lme(vel.ad)

# Plotting model predictions

plot(effect("Species2", vel.ad))

########## 4.2) VELOCITY - Juveniles #########

vel.juv <- lmer(Max_velocity_cm_s ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aJ)

summary(vel.juv)
anova(vel.juv)

# model validation

plot(vel.juv, which=c(1)) 
res.vel.juv <- resid(vel.juv)

hist(res.vel.juv)
qqPlot(res.vel.juv) 

plot(res.vel.juv ~ aJ$Species)
plot(res.vel.juv ~ aJ$Dist_to_stimulus)
plot(res.vel.juv ~ aJ$Angle_to_stimulus)
plot(res.vel.juv ~ aJ$Video)
plot(res.vel.juv ~ aJ$Observer)

vif.lme(vel.juv)

# Plotting model predictions

plot(effect("Species2", vel.juv))


########## 5.1) TURNING RATE - Adults #########

tur.ad <- lmer(Turning_rate_ms ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aA)

summary(tur.ad)
anova(tur.ad)

# model validation

plot(tur.ad, which=c(1)) 
res.tur.ad <- resid(tur.ad)

hist(res.tur.ad)
qqPlot(res.tur.ad) 

prov <- subset(aA, Turning_rate_ms!="NA") # there are 3 NAs in the turning rate variable, thus I first create a subset without the NAs for the plots to work.

plot(res.tur.ad ~ prov$Species2)
plot(res.tur.ad ~ prov$Dist_to_stimulus)
plot(res.tur.ad ~ prov$Angle_to_stimulus)
plot(res.tur.ad ~ prov$Video)
plot(res.tur.ad ~ prov$Observer)

vif.lme(tur.ad)

# Plotting model predictions

plot(effect("Species2", tur.ad))


########## 5.2) TURNING RATE - Juveniles #########

tur.juv <- lmer(Turning_rate_ms ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aJ)

summary(tur.juv)
anova(tur.juv)

# model validation

plot(tur.juv, which=c(1)) 
res.tur.juv <- resid(tur.juv)

hist(res.tur.juv)
qqPlot(res.tur.juv) 

plot(res.tur.juv ~ aJ$Species)
plot(res.tur.juv ~ aJ$Dist_to_stimulus)
plot(res.tur.juv ~ aJ$Angle_to_stimulus)
plot(res.tur.juv ~ aJ$Video)
plot(res.tur.juv ~ aJ$Observer)

vif.lme(tur.juv)

# Plotting model predictions

plot(effect("Species2", tur.juv))


########## 6.1) CUMULATIVE DISTANCE from stimulus onset - Adults #########

cum2.ad <- lmer(Cum_dist_stim_14fr ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aA)

summary(cum2.ad)
anova(cum2.ad)

# model validation

plot(cum2.ad, which=c(1)) 
res.cum2.ad <- resid(cum2.ad)

hist(res.cum2.ad)
qqPlot(res.cum2.ad) 

plot(res.cum2.ad ~ aA$Species)
plot(res.cum2.ad ~ aA$Dist_to_stimulus)
plot(res.cum2.ad ~ aA$Angle_to_stimulus)
plot(res.cum2.ad ~ aA$Video)
plot(res.cum2.ad ~ aA$Observer)

vif.lme(cum2.ad)

# Plotting model predictions

plot(effect("Species2", cum2.ad))


########## 6.2) CUMULATIVE DISTANCE from stimulus onset - Juveniles #########

cum2.juv <- lmer(Cum_dist_stim_14fr ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aJ)

summary(cum2.juv)
anova(cum2.juv)

# model validation

plot(cum2.juv, which=c(1)) 
res.cum2.juv <- resid(cum2.juv)

hist(res.cum2.juv)
qqPlot(res.cum2.juv) 

plot(res.cum2.juv ~ aJ$Species)
plot(res.cum2.juv ~ aJ$Dist_to_stimulus)
plot(res.cum2.juv ~ aJ$Angle_to_stimulus)
plot(res.cum2.juv ~ aJ$Video)
plot(res.cum2.juv ~ aJ$Observer)

vif.lme(cum2.juv)

# Plotting model predictions

plot(effect("Species2", cum2.juv))


##################################
# Get the maximum VIF across the entire analysis

VIF1 <- c(vif.lme(lat.ad), vif.lme(lat.juv), vif.lme(cum.ad), vif.lme(cum.juv), vif.lme(acc.ad), vif.lme(acc.juv), vif.lme(vel.ad), vif.lme(vel.juv), vif.lme(tur.ad), vif.lme(tur.juv), vif.lme(cum2.ad), vif.lme(cum2.juv))
max(VIF1)
mean(VIF1)
plot(VIF1)

###############################################################
####### PLotting for the MS ###################################
###############################################################

# latency

postscript(file="Latency.ps", width=3.9, height=4.1, pointsize=10)
groups.lat <- factor(a$Species2)
o.lat <- sort.list(as.numeric(groups.lat), decreasing=T)
tmp.lat <- a[o.lat,]

dotchart(tmp.lat$Latency_ms, groups= factor(tmp.lat$Species2), xlab="Latency [ms]", main=NULL, color=tmp.lat$color, pch=tmp.lat$pch, lty=1)
dev.off()

postscript(file="LatencyA-effects.ps", width=2.07, height=3.9)
plot(effect("Species2", lat.ad), colors=c("black", "black"), xlab=NULL, lty=0, main=NULL, ylab=NULL, rotx=90, cex=0.5, roty=90, ylim=c(2,4.2))
dev.off()

postscript(file="LatencyJ-effects.ps", width=2.07, height=3.9)
plot(effect("Species2", lat.juv), colors=c("darkgrey", "black"), xlab=NULL, lty=0, main=NULL, ylab=NULL, rotx=90, cex=0.5, roty=90, ylim=c(2,4.2))
dev.off()


# velocity 

postscript(file="Velocity.ps", width=3.9, height=4.1, pointsize=10)
groups.vel <- factor(a$Species2)
o.vel <- sort.list(as.numeric(groups.vel), decreasing=T)
tmp.vel <- a[o.vel,]

dotchart(tmp.vel$Max_velocity_cm_s, groups= factor(tmp.vel$Species2), xlab="Velocity [cm/s]", main=NULL, color= tmp.vel$color, pch=tmp.vel$pch, lty=1)
dev.off()

postscript(file="VelocityA-effects.ps", width=2.07, height=3.9)
plot(effect("Species2", vel.ad), colors=c("black", "black"), xlab=NULL, lty=0, main=NULL, ylab=NULL, rotx=90, cex=0.5, roty=90, ylim=c(80,210))
dev.off()

postscript(file="VelocityJ-effects.ps", width=2.07, height=3.9)
plot(effect("Species2", vel.juv), colors=c("darkgrey", "black"), xlab=NULL, lty=0, main=NULL, ylab=NULL, rotx=90, cex=0.5, roty=90, ylim=c(80,210))
dev.off()


# Acceleration

postscript(file="Acceleration.ps", width=3.9, height=4.1, pointsize=10)
groups.acc <- factor(a$Species2)
o.acc <- sort.list(as.numeric(groups.acc), decreasing=T)
tmp.acc <- a[o.acc,]

dotchart(tmp.acc$Max_acceleration_m_s2, groups= factor(tmp.acc$Species2), xlab="Acceleration [m/s2]", main=NULL, color= tmp.acc$color, pch= tmp.acc$pch, lty=1)
dev.off()

postscript(file="AccelerationA-effects.ps", width=2.07, height=3.9)
plot(effect("Species2", acc.ad), colors=c("black", "black"), xlab=NULL, lty=0, main=NULL, ylab=NULL, rotx=90, cex=0.5, roty=90, ylim=c(60,160))
dev.off()

postscript(file="AccelerationJ-effects.ps", width=2.07, height=3.9)
plot(effect("Species2", acc.juv), colors=c("darkgrey", "black"), xlab=NULL, lty=0, main=NULL, ylab=NULL, rotx=90, cex=0.5, roty=90, ylim=c(60,160))
dev.off()

# Distance (from response onset)

postscript(file="Cumulative_distance1.ps", width=3.9, height=4.1, pointsize=10)
groups.dist <- factor(a$Species2)
o.dist <- sort.list(as.numeric(groups.dist), decreasing=T)
tmp.dist <- a[o.dist,]

dotchart(tmp.dist$Cum_dist2, groups= factor(tmp.dist$Species2), xlab="Distance [cm]", main=NULL, color= tmp.dist$color, pch= tmp.dist$pch, lty=1)
dev.off()

postscript(file="Cumulative_distance1A.ps", width=2.07, height=3.9)
plot(effect("Species2", cum.ad), colors=c("black", "black"), xlab=NULL, lty=0, main=NULL, ylab=NULL, rotx=90, cex=0.5, roty=90, ylim=c(1.7,3.6))
dev.off()

postscript(file="Cumulative_distance1J.ps", width=2.07, height=3.9)
plot(effect("Species2", cum.juv), colors=c("darkgrey", "black"), xlab=NULL, lty=0, main=NULL, ylab=NULL, rotx=90, cex=0.5, roty=90, ylim=c(1.7,3.6))
dev.off()

# Distance 2 (from stimulus onset)

postscript(file="Cumulative_distance2.ps", width=3.9, height=4.1, pointsize=10)
groups.cum <- factor(a$Species2)
o.cum <- sort.list(as.numeric(groups.cum), decreasing=T)
tmp.cum <- a[o.cum,]

dotchart(tmp.cum$Cum_dist_stim_14fr, groups= factor(tmp.cum$Species2), xlab="Distance [cm]", main=NULL, color= tmp.cum$color, pch= tmp.cum$pch, lty=1)
dev.off()

postscript(file="Cumulative_distance2A.ps", width=2.07, height=3.9)
plot(effect("Species2", cum2.ad), colors=c("black", "black"), xlab=NULL, lty=0, main=NULL, ylab=NULL, rotx=90, cex=0.5, roty=90, ylim=c(0.2,2.7))
dev.off()

postscript(file="Cumulative_distance2J.ps", width=2.07, height=3.9)
plot(effect("Species2", cum2.juv), colors=c("darkgrey", "black"), xlab=NULL, lty=0, main=NULL, ylab=NULL, rotx=90, cex=0.5, roty=90, ylim=c(0.2,2.7))
dev.off()


# Turning rate

postscript(file="Turning_rate.ps", width=3.9, height=4.1, pointsize=10)
groups.tur <- factor(a$Species2)
o.tur <- sort.list(as.numeric(groups.tur), decreasing=T)
tmp.tur <- a[o.tur,]

dotchart(tmp.tur$Turning_rate_ms, groups= factor(tmp.tur$Species2), xlab="Turning rate [degrees/ms]", main=NULL, color= tmp.tur$color, pch=tmp.tur$pch, lty=1)
dev.off()

postscript(file="Turning_rateA.ps", width=2.07, height=3.9)
plot(effect("Species2", tur.ad), colors=c("black", "black"), xlab=NULL, lty=0, main=NULL, ylab=NULL, rotx=90, cex=0.5, roty=90, ylim=c(1,9))
dev.off()

postscript(file="Turning_rateJ.ps", width=2.07, height=3.9)
plot(effect("Species2", tur.juv), colors=c("darkgrey", "black"), xlab=NULL, lty=0, main=NULL, ylab=NULL, rotx=90, cex=0.5, roty=90, ylim=c(1,9))
dev.off()


###############################################################################################################################
######################## lmer Analysis including body size as a fixed effect ##################################################
###############################################################################################################################


########## 1.1) LATENCY - Adults #########

lat.ad <- lmer(log(Latency_ms) ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + TL + Species2 + (1|Individual), data=aA)

summary(lat.ad)
anova(lat.ad)

# model validation

plot(lat.ad, which=c(1)) 
res.lat.ad <- resid(lat.ad)

hist(res.lat.ad)
qqPlot(res.lat.ad) 

plot(res.lat.ad ~ aA$Species)
plot(res.lat.ad ~ aA$Dist_to_stimulus)
plot(res.lat.ad ~ aA$Angle_to_stimulus)
plot(res.lat.ad ~ aA$Video)
plot(res.lat.ad ~ aA$Observer)

vif.lme(lat.ad)

# Plotting model predictions

plot(effect("Species2", lat.ad))


########## 1.2) LATENCY - Juveniles #########

lat.juv <- lmer(log(Latency_ms) ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + TL + Species2 + (1|Individual), data=aJ)

summary(lat.juv)
anova(lat.juv)

# model validation

plot(lat.juv, which=c(1)) 
res.lat.juv <- resid(lat.juv)

hist(res.lat.juv)
qqPlot(res.lat.juv) 

plot(res.lat.juv ~ aJ$Species)
plot(res.lat.juv ~ aJ$Dist_to_stimulus)
plot(res.lat.juv ~ aJ$Angle_to_stimulus)
plot(res.lat.juv ~ aJ$Video)
plot(res.lat.juv ~ aJ$Observer)

vif.lme(lat.juv)

# Plotting model predictions

plot(effect("Species2", lat.juv))

########## 2.1) CUMULATIVE DISTANCE - Adults #########

cum.ad <- lmer(Cum_dist2 ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + TL + Species2 + (1|Individual), data=aA)

summary(cum.ad)
anova(cum.ad)

# model validation

plot(cum.ad, which=c(1)) 
res.cum.ad <- resid(cum.ad)

hist(res.cum.ad)
qqPlot(res.cum.ad) 

plot(res.cum.ad ~ aA$Species)
plot(res.cum.ad ~ aA$Dist_to_stimulus)
plot(res.cum.ad ~ aA$Angle_to_stimulus)
plot(res.cum.ad ~ aA$Video)
plot(res.cum.ad ~ aA$Observer)

vif.lme(cum.ad)

# Plotting model predictions

plot(effect("Species2", cum.ad))


########## 2.2) CUMULATIVE DISTANCE - Juveniles #########

cum.juv <- lmer(Cum_dist2 ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + TL + Species2 + (1|Individual), data=aJ)

summary(cum.juv)
anova(cum.juv)

# model validation

plot(cum.juv, which=c(1)) 
res.cum.juv <- resid(cum.juv)

hist(res.cum.juv)
qqPlot(res.cum.juv) 

plot(res.cum.juv ~ aJ$Species)
plot(res.cum.juv ~ aJ$Dist_to_stimulus)
plot(res.cum.juv ~ aJ$Angle_to_stimulus)
plot(res.cum.juv ~ aJ$Video)
plot(res.cum.juv ~ aJ$Observer)

vif.lme(cum.juv)

# Plotting model predictions

plot(effect("Species2", cum.juv))


########## 3.1) ACCELERATION - Adults #########

acc.ad <- lmer(Max_acceleration_m_s2 ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + TL + Species2 + (1|Individual), data=aA)

summary(acc.ad)
anova(acc.ad)

# model validation

plot(acc.ad, which=c(1)) 
res.acc.ad <- resid(acc.ad)

hist(res.acc.ad)
qqPlot(res.acc.ad) 

plot(res.acc.ad ~ aA$Species)
plot(res.acc.ad ~ aA$Dist_to_stimulus)
plot(res.acc.ad ~ aA$Angle_to_stimulus)
plot(res.acc.ad ~ aA$Video)
plot(res.acc.ad ~ aA$Observer)

vif.lme(acc.ad)

# Plotting model predictions

plot(effect("Species2", acc.ad))


########## 3.2) ACCELERATION - Juveniles #########

acc.juv <- lmer(Max_acceleration_m_s2 ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + TL + Species2 + (1|Individual), data=aJ)

summary(acc.juv)
anova(acc.juv)

# model validation

plot(acc.juv, which=c(1)) 
res.acc.juv <- resid(acc.juv)

hist(res.acc.juv)
qqPlot(res.acc.juv) 

plot(res.acc.juv ~ aJ$Species)
plot(res.acc.juv ~ aJ$Dist_to_stimulus)
plot(res.acc.juv ~ aJ$Angle_to_stimulus)
plot(res.acc.juv ~ aJ$Video)
plot(res.acc.juv ~ aJ$Observer)

vif.lme(acc.juv)

# Plotting model predictions

plot(effect("Species2", acc.juv))


########## 4.1) VELOCITY - Adults #########

vel.ad <- lmer(Max_velocity_cm_s ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + TL + Species2 + (1|Individual), data=aA)

summary(vel.ad)
anova(vel.ad)

# model validation

plot(vel.ad, which=c(1)) 
res.vel.ad <- resid(vel.ad)

hist(res.vel.ad)
qqPlot(res.vel.ad) 

plot(res.vel.ad ~ aA$Species)
plot(res.vel.ad ~ aA$Dist_to_stimulus)
plot(res.vel.ad ~ aA$Angle_to_stimulus)
plot(res.vel.ad ~ aA$Video)
plot(res.vel.ad ~ aA$Observer)

vif.lme(vel.ad)

# Plotting model predictions

plot(effect("Species2", vel.ad))


########## 4.2) VELOCITY - Juveniles #########

vel.juv <- lmer(Max_velocity_cm_s ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + TL + Species2 + (1|Individual), data=aJ)

summary(vel.juv)
anova(vel.juv)

# model validation

plot(vel.juv, which=c(1)) 
res.vel.juv <- resid(vel.juv)

hist(res.vel.juv)
qqPlot(res.vel.juv) 

plot(res.vel.juv ~ aJ$Species)
plot(res.vel.juv ~ aJ$Dist_to_stimulus)
plot(res.vel.juv ~ aJ$Angle_to_stimulus)
plot(res.vel.juv ~ aJ$Video)
plot(res.vel.juv ~ aJ$Observer)

vif.lme(vel.juv)

# Plotting model predictions

plot(effect("Species2", vel.juv))


########## 5.1) TURNING RATE - Adults #########

tur.ad <- lmer(Turning_rate_ms ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + TL + Species2 + (1|Individual), data=aA)

summary(tur.ad)
anova(tur.ad)

# model validation

plot(tur.ad, which=c(1)) 
res.tur.ad <- resid(tur.ad)

hist(res.tur.ad)
qqPlot(res.tur.ad) 

prov <- subset(aA, Turning_rate_ms!="NA") # there are 3 NAs in the turning rate variable, thus I first create a subset without the NAs for the plots to work.

plot(res.tur.ad ~ prov$Species2)
plot(res.tur.ad ~ prov$Dist_to_stimulus)
plot(res.tur.ad ~ prov$Angle_to_stimulus)
plot(res.tur.ad ~ prov$Video)
plot(res.tur.ad ~ prov$Observer)

vif.lme(tur.ad)

# Plotting model predictions

plot(effect("Species2", tur.ad))


########## 5.2) TURNING RATE - Juveniles #########

tur.juv <- lmer(Turning_rate_ms ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + TL + Species2 + (1|Individual), data=aJ)

summary(tur.juv)
anova(tur.juv)

# model validation

plot(tur.juv, which=c(1)) 
res.tur.juv <- resid(tur.juv)

hist(res.tur.juv)
qqPlot(res.tur.juv) 

plot(res.tur.juv ~ aJ$Species)
plot(res.tur.juv ~ aJ$Dist_to_stimulus)
plot(res.tur.juv ~ aJ$Angle_to_stimulus)
plot(res.tur.juv ~ aJ$Video)
plot(res.tur.juv ~ aJ$Observer)

vif.lme(tur.juv)

# Plotting model predictions

plot(effect("Species2", tur.juv))


########## 6.1) CUMULATIVE DISTANCE from stimulus onset - Adults #########

cum2.ad <- lmer(Cum_dist_stim_14fr ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + TL + Species2 + (1|Individual), data=aA)

summary(cum2.ad)
anova(cum2.ad)

# model validation

plot(cum2.ad, which=c(1)) 
res.cum2.ad <- resid(cum2.ad)

hist(res.cum2.ad)
qqPlot(res.cum2.ad) 

plot(res.cum2.ad ~ aA$Species)
plot(res.cum2.ad ~ aA$Dist_to_stimulus)
plot(res.cum2.ad ~ aA$Angle_to_stimulus)
plot(res.cum2.ad ~ aA$Video)
plot(res.cum2.ad ~ aA$Observer)

vif.lme(cum2.ad)

# Plotting model predictions

plot(effect("Species2", cum2.ad))

########## 6.2) CUMULATIVE DISTANCE from stimulus onset - Juveniles #########

cum2.juv <- lmer(Cum_dist_stim_14fr ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + TL + Species2 + (1|Individual), data=aJ)

summary(cum2.juv)
anova(cum2.juv)

# model validation

plot(cum2.juv, which=c(1)) 
res.cum2.juv <- resid(cum2.juv)

hist(res.cum2.juv)
qqPlot(res.cum2.juv) 

plot(res.cum2.juv ~ aJ$Species)
plot(res.cum2.juv ~ aJ$Dist_to_stimulus)
plot(res.cum2.juv ~ aJ$Angle_to_stimulus)
plot(res.cum2.juv ~ aJ$Video)
plot(res.cum2.juv ~ aJ$Observer)

vif.lme(cum2.juv)

# Plotting model predictions

plot(effect("Species2", cum2.juv))

##################################
# Get the maximum VIFs across the entire analysis

VIF2 <- c(vif.lme(lat.ad), vif.lme(lat.juv), vif.lme(cum.ad), vif.lme(cum.juv), vif.lme(acc.ad), vif.lme(acc.juv), vif.lme(vel.ad), vif.lme(vel.juv), vif.lme(tur.ad), vif.lme(tur.juv), vif.lme(cum2.ad), vif.lme(cum2.juv))
max(VIF2)
mean(VIF2)
median(VIF2)
plot(VIF2)

#for comparison, here's again the VIFs from the original analysis.

max(VIF1)
mean(VIF1)
median(VIF1)
plot(VIF1)


########################################################################################################################################################################################
######################## lmer Analysis with variables Cumulative distance, Max. Acceleration & Max. Velocity corrected for body size####################################################
########################################################################################################################################################################################

# Checking for colinearity between predictors

df.ad <- data.frame(aA$Angle_to_stimulus_c, aA$Dist_to_stimulus, aA$Video, aA$Observer, aA$TL, aA$Species2)
ggpairs(df.ad)

df.juv <- data.frame(aJ$Angle_to_stimulus_c, aJ$Dist_to_stimulus, aJ$Video, aJ$Observer, aJ$TL, aJ$Species2)
ggpairs(df.juv)

# we see that species & total length (TL) are colinear in our dataset, particularly for the adults


# correcting the variables for body length

aA$Max_velocity_bl_s <- aA$Max_velocity_cm_s/aA$TL
aA$Max_acceleration_bl_s2 <- aA$Max_acceleration_m_s2/(aA$TL*100)
aA$Cum_dist_stim_14fr_bl <- ifelse(aA$Cum_dist_stim_14fr!=0, aA$Cum_dist_stim_14fr/aA$TL, 0)
aA$Cum_dist2_bl <- aA$Cum_dist2/aA$TL

aJ$Max_velocity_bl_s <- aJ$Max_velocity_cm_s/aJ$TL
aJ$Max_acceleration_bl_s2 <- aJ$Max_acceleration_m_s2/(aJ$TL*100)
aJ$Cum_dist_stim_14fr_bl <- aJ$Cum_dist_stim_14fr/aJ$TL
aJ$Cum_dist2_bl <- aJ$Cum_dist2/aJ$TL

########## 2.1) CUMULATIVE DISTANCE - Adults #########

cum.ad <- lmer(log(Cum_dist2_bl) ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aA)
# log transformed for a better fit of the model

summary(cum.ad)
anova(cum.ad)

# model validation

plot(cum.ad, which=c(1)) 
res.cum.ad <- resid(cum.ad)

hist(res.cum.ad)
qqPlot(res.cum.ad) 

plot(res.cum.ad ~ aA$Species)
plot(res.cum.ad ~ aA$Dist_to_stimulus)
plot(res.cum.ad ~ aA$Angle_to_stimulus)
plot(res.cum.ad ~ aA$Video)
plot(res.cum.ad ~ aA$Observer)

# Plotting model predictions

plot(effect("Species2", cum.ad))


########## 2.2) CUMULATIVE DISTANCE - Juveniles #########

cum.juv <- lmer(log(Cum_dist2_bl) ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aJ)
# log transformed for a better fit of the model

summary(cum.juv)
anova(cum.juv)

# model validation

plot(cum.juv, which=c(1)) 
res.cum.juv <- resid(cum.juv)

hist(res.cum.juv)
qqPlot(res.cum.juv) 

plot(res.cum.juv ~ aJ$Species)
plot(res.cum.juv ~ aJ$Dist_to_stimulus)
plot(res.cum.juv ~ aJ$Angle_to_stimulus)
plot(res.cum.juv ~ aJ$Video)
plot(res.cum.juv ~ aJ$Observer)

# Plotting model predictions

plot(effect("Species2", cum.juv))

########## 3.1) ACCELERATION - Adults #########

acc.ad <- lmer(log(Max_acceleration_bl_s2) ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aA)
# log transformed for a better fit of the model 

summary(acc.ad)
anova(acc.ad)

# model validation

plot(acc.ad, which=c(1)) 
res.acc.ad <- resid(acc.ad)

hist(res.acc.ad)
qqPlot(res.acc.ad) 

plot(res.acc.ad ~ aA$Species)
plot(res.acc.ad ~ aA$Dist_to_stimulus)
plot(res.acc.ad ~ aA$Angle_to_stimulus)
plot(res.acc.ad ~ aA$Video)
plot(res.acc.ad ~ aA$Observer)

# Plotting model predictions

plot(effect("Species2", acc.ad))

########## 3.2) ACCELERATION - Juveniles #########

acc.juv <- lmer(log(Max_acceleration_bl_s2) ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aJ)

summary(acc.juv)
anova(acc.juv)

# model validation

plot(acc.juv, which=c(1)) 
res.acc.juv <- resid(acc.juv)

hist(res.acc.juv)
qqPlot(res.acc.juv) 

plot(res.acc.juv ~ aJ$Species)
plot(res.acc.juv ~ aJ$Dist_to_stimulus)
plot(res.acc.juv ~ aJ$Angle_to_stimulus)
plot(res.acc.juv ~ aJ$Video)
plot(res.acc.juv ~ aJ$Observer)

# Plotting model predictions

plot(effect("Species2", acc.juv))

########## 4.1) VELOCITY - Adults #########

vel.ad <- lmer(log(Max_velocity_bl_s) ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aA)
# log transformed for a better fit of the model 

summary(vel.ad)
anova(vel.ad)

# model validation

plot(vel.ad, which=c(1)) 
res.vel.ad <- resid(vel.ad)

hist(res.vel.ad)
qqPlot(res.vel.ad) 

plot(res.vel.ad ~ aA$Species)
plot(res.vel.ad ~ aA$Dist_to_stimulus)
plot(res.vel.ad ~ aA$Angle_to_stimulus)
plot(res.vel.ad ~ aA$Video)
plot(res.vel.ad ~ aA$Observer)

# Plotting model predictions

plot(effect("Species2", vel.ad))


########## 1.2) VELOCITY - Juveniles #########

vel.juv <- lmer(Max_velocity_bl_s ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aJ)

summary(vel.juv)
anova(vel.juv)

# model validation

plot(vel.juv, which=c(1)) 
res.vel.juv <- resid(vel.juv)

hist(res.vel.juv)
qqPlot(res.vel.juv) 

plot(res.vel.juv ~ aJ$Species)
plot(res.vel.juv ~ aJ$Dist_to_stimulus)
plot(res.vel.juv ~ aJ$Angle_to_stimulus)
plot(res.vel.juv ~ aJ$Video)
plot(res.vel.juv ~ aJ$Observer)

# Plotting model predictions

plot(effect("Species2", vel.juv))

########## 6.1) CUMULATIVE DISTANCE from stimulus onset - Adults #########

cum2.ad <- lmer(Cum_dist_stim_14fr_bl ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aA)

summary(cum2.ad)
anova(cum2.ad)

# model validation

plot(cum2.ad, which=c(1)) 
res.cum2.ad <- resid(cum2.ad)

hist(res.cum2.ad)
qqPlot(res.cum2.ad) 

plot(res.cum2.ad ~ aA$Species)
plot(res.cum2.ad ~ aA$Dist_to_stimulus)
plot(res.cum2.ad ~ aA$Angle_to_stimulus)
plot(res.cum2.ad ~ aA$Video)
plot(res.cum2.ad ~ aA$Observer)

# Plotting model predictions

plot(effect("Species2", cum2.ad))


########## 6.2) CUMULATIVE DISTANCE from stimulus onset - Juveniles #########

cum2.juv <- lmer(Cum_dist_stim_14fr_bl ~  sin(Angle_to_stimulus_c) + Dist_to_stimulus_c + Video + Observer + Species2 + (1|Individual), data=aJ)

summary(cum2.juv)
anova(cum2.juv)

# model validation

plot(cum2.juv, which=c(1)) 
res.cum2.juv <- resid(cum2.juv)

hist(res.cum2.juv)
qqPlot(res.cum2.juv) 

plot(res.cum2.juv ~ aJ$Species)
plot(res.cum2.juv ~ aJ$Dist_to_stimulus)
plot(res.cum2.juv ~ aJ$Angle_to_stimulus)
plot(res.cum2.juv ~ aJ$Video)
plot(res.cum2.juv ~ aJ$Observer)

# Plotting model predictions

plot(effect("Species2", cum2.juv))

###########################################################################################
############## Field Data Analysis (time spend hiding within the reef) ####################
###########################################################################################

library(agricolae)

data <- read.table("Field_data.txt", header=T)
summary(data)

# % of time hiding in reef matrix

plot(per_t_hid~species, data=data)


(kruskal(data$per_t_hid, data$species, p.adj="holm"))